(create-nats-streaming cluster-name client-id & urls)creates a Nats Streaming connection, returning a Nats object
creates a Nats Streaming connection, returning a Nats object - cluster-name : nats streaming cluster name - client-id : unique client id - urls : nats server urls, either a seq or comma separated
(create-nats-subscription-callback nats
subject
{:keys [queue durable-name max-in-flight]
:as opts}
cb)(publisher nats subject-or-fn)returns a Manifold sink-only stream which publishes items put on the stream to NATS
returns a Manifold sink-only stream which publishes items put on the stream to NATS
(pubsub nats subject)(pubsub nats subject opts)returns a Manifold source+sink stream for a single NATS subject. the source returns INatsMessages, while the sink accepts strings
returns a Manifold source+sink stream for a single NATS subject. the source returns INatsMessages, while the sink accepts strings
(subscriber nats subject)(subscriber nats subject opts)returns a a Manifold source-only stream of INatsMessages from a NATS subject. close the stream to dispose of the subscription
returns a a Manifold source-only stream of INatsMessages from a NATS subject. close the stream to dispose of the subscription
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |